# Generated by Django 5.2.7 on 2025-10-22 06:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rebac', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='typedefinition',
            name='model',
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
