# Generated by Django 5.2.7 on 2025-10-25 16:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rebac', '0002_typedefinition_model'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResourceNode',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=255)),
                ('slug', models.SlugField(blank=True, max_length=255)),
                ('metadata', models.JSONField(blank=True, default=dict)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('parent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='django_rebac.resourcenode')),
            ],
            options={
                'verbose_name': 'Resource node',
                'verbose_name_plural': 'Resource nodes',
            },
        ),
    ]
