# Generated by Django 5.2.7 on 2025-12-01 09:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rebac', '0004_add_hierarchy_models'),
    ]

    operations = [
        migrations.AlterField(
            model_name='hierarchynoderole',
            name='role',
            field=models.CharField(choices=[('owner', 'Owner'), ('manager', 'Manager'), ('viewer', 'Viewer'), ('admin', 'Admin'), ('lead', 'Lead'), ('member', 'Member')], default='manager', max_length=64),
        ),
    ]
